==> ejc-assistrmat-api-3.0.0-20220414.072734-71-sources.jar: com/ejianc/business/assist/material/vo/MaterialCheckDetailVO.java <==
package com.ejianc.business.assist.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 验收单明细
 * 
 * @author generator
 * 
 */
public class MaterialCheckDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long checkId; // 验收主键ID
    private Long deliveryId; // 发货主键ID
    private Long deliveryDetailId; // 发货明细主键ID
    private Long orderId; // 订单主键ID
    private Long orderDetailId; // 订单明细主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private BigDecimal deliverNumsSum; // 送货数量
    private BigDecimal checkNumsSum; // 验收数量
    private String memo; // 备注
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date rmatDate; // 计租日期
    private Long unitId; // 单位id
    private String unitName; // 单位名称
    private Long contractDetailId; // 合同明细来源主键
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    private BigDecimal contractNumsSum; // 合同数量

    private BigDecimal numM; // 主数量
    private Long unitMId; // 主单位
    private String unitMName; // 主单位名称
    private String passMuster; // 是否符合要求(0-否，1-是)
    private BigDecimal roughWeight; // 毛重
    private BigDecimal tare; // 皮重
    private BigDecimal netWeight; // 净重
    private BigDecimal theoreticalWeight; // 理论重量
    private BigDecimal transScale; // 转换系数
    private BigDecimal deviationRate; // 偏差率
    private BigDecimal measureNumsSum; // 计量数量
    private String conversionUnit; // 重量转换系数单位
    private BigDecimal transScaleSecond; // 第二次转换系数(主单位 - 吨)


    public BigDecimal getContractNumsSum() {
        return contractNumsSum;
    }

    public void setContractNumsSum(BigDecimal contractNumsSum) {
        this.contractNumsSum = contractNumsSum;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public String getPassMuster() {
        return passMuster;
    }

    public void setPassMuster(String passMuster) {
        this.passMuster = passMuster;
    }

    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }

    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public BigDecimal getTheoreticalWeight() {
        return theoreticalWeight;
    }

    public void setTheoreticalWeight(BigDecimal theoreticalWeight) {
        this.theoreticalWeight = theoreticalWeight;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }

    public BigDecimal getMeasureNumsSum() {
        return measureNumsSum;
    }

    public void setMeasureNumsSum(BigDecimal measureNumsSum) {
        this.measureNumsSum = measureNumsSum;
    }

    public String getConversionUnit() {
        return conversionUnit;
    }

    public void setConversionUnit(String conversionUnit) {
        this.conversionUnit = conversionUnit;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    public void setDeliveryDetailId(Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getOrderDetailId() {
        return orderDetailId;
    }

    public void setOrderDetailId(Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getRmatDate() {
        return rmatDate;
    }

    public void setRmatDate(Date rmatDate) {
        this.rmatDate = rmatDate;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }

    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public BigDecimal getTransScaleSecond() {
        return transScaleSecond;
    }

    public void setTransScaleSecond(BigDecimal transScaleSecond) {
        this.transScaleSecond = transScaleSecond;
    }
}

==> ejc-assistrmat-api-3.0.0-20220915.064758-213-sources.jar: com/ejianc/business/assist/material/vo/MaterialCheckDetailVO.java <==
package com.ejianc.business.assist.material.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 验收单明细
 * 
 * @author generator
 * 
 */
public class MaterialCheckDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long checkId; // 验收主键ID
    private Long deliveryId; // 发货主键ID
    private Long deliveryDetailId; // 发货明细主键ID
    private Long orderId; // 订单主键ID
    private Long orderDetailId; // 订单明细主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private BigDecimal deliverNumsSum; // 送货数量
    private BigDecimal checkNumsSum; // 验收数量
    private String memo; // 备注
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date rmatDate; // 计租日期
    private Long unitId; // 单位id
    private String unitName; // 单位名称
    private Long contractDetailId; // 合同明细来源主键
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    private BigDecimal contractNumsSum; // 合同数量

    private BigDecimal numM; // 主数量
    private Long unitMId; // 主单位
    private String unitMName; // 主单位名称
    private String passMuster; // 是否符合要求(0-否，1-是)
    private BigDecimal roughWeight; // 毛重
    private BigDecimal tare; // 皮重
    private BigDecimal netWeight; // 净重
    private BigDecimal theoreticalWeight; // 理论重量
    private BigDecimal transScale; // 转换系数
    private BigDecimal deviationRate; // 偏差率
    private BigDecimal measureNumsSum; // 计量数量
    private String conversionUnit; // 重量转换系数单位
    private BigDecimal transScaleSecond; // 第二次转换系数(主单位 - 吨)

    private BigDecimal unitPrice; //单价(无税)
    private BigDecimal unitTaxPrice; //单价(含税)
    private BigDecimal mny; //金额(无税)
    private BigDecimal taxMny;  //金额(含税)
    private BigDecimal taxRate; //税率
    private String brand; //品牌
    private BigDecimal tax;  //税额

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }

    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public BigDecimal getContractNumsSum() {
        return contractNumsSum;
    }

    public void setContractNumsSum(BigDecimal contractNumsSum) {
        this.contractNumsSum = contractNumsSum;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public String getPassMuster() {
        return passMuster;
    }

    public void setPassMuster(String passMuster) {
        this.passMuster = passMuster;
    }

    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }

    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public BigDecimal getTheoreticalWeight() {
        return theoreticalWeight;
    }

    public void setTheoreticalWeight(BigDecimal theoreticalWeight) {
        this.theoreticalWeight = theoreticalWeight;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }

    public BigDecimal getMeasureNumsSum() {
        return measureNumsSum;
    }

    public void setMeasureNumsSum(BigDecimal measureNumsSum) {
        this.measureNumsSum = measureNumsSum;
    }

    public String getConversionUnit() {
        return conversionUnit;
    }

    public void setConversionUnit(String conversionUnit) {
        this.conversionUnit = conversionUnit;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    public void setDeliveryDetailId(Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getOrderDetailId() {
        return orderDetailId;
    }

    public void setOrderDetailId(Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    public void setDeliverNumsSum(BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getRmatDate() {
        return rmatDate;
    }

    public void setRmatDate(Date rmatDate) {
        this.rmatDate = rmatDate;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }

    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public BigDecimal getTransScaleSecond() {
        return transScaleSecond;
    }

    public void setTransScaleSecond(BigDecimal transScaleSecond) {
        this.transScaleSecond = transScaleSecond;
    }
}
